pub struct ImagePresentation { /* private fields */ }Expand description
Canonical policy for composing an Image into a fixed cell rectangle.
Implementations
Sourceimpl ImagePresentation
impl ImagePresentation
Sourcepub fn from_theme(theme: &Theme) -> Self
pub fn from_theme(theme: &Theme) -> Self
Derives the canonical image fallback style from an Urushi theme.
pub const fn get_fallback_style(&self) -> &TextStyle
pub fn fallback_style(self, style: TextStyle) -> Self